The following tasks implement steps action space paradigms:

- [AntiReach](../envs.md#neurogym.envs.native.antireach.AntiReach)
- [Reaching1D](../envs.md#neurogym.envs.native.reaching.Reaching1D)
- [Reaching1DWithSelfDistraction](../envs.md#neurogym.envs.native.reaching.Reaching1DWithSelfDistraction)
